TextFilter

Trait TextFilter 

pub trait TextFilter {
    // Required method
    fn preprocess(&self, s: String) -> String;
}
Trait for preprocessing text data from XML.

This may be used by codecs to allow to customize some of their behaviour.

Required Methods

fn preprocess(&self, s: String) -> String

Process the incoming string and return the result of the processing.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors